@@ -1,9 +1,9 @@
 package App::dateseq;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-22'; # DATE
+our $DATE = '2021-08-23'; # DATE
 our $DIST = 'App-dateseq'; # DIST
-our $VERSION = '0.103'; # VERSION
+our $VERSION = '0.104'; # VERSION
 
 use 5.010001;
 use strict;
@@ -443,7 +443,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.103 of App::dateseq (from Perl distribution App-dateseq), released on 2021-08-22.
+This document describes version 0.104 of App::dateseq (from Perl distribution App-dateseq), released on 2021-08-23.
 
 =head1 FUNCTIONS
 
@@ -574,18 +574,27 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-datese
 
 Source repository is at L<https://github.com/perlancar/perl-App-dateseq>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dateseq>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2021, 2020, 2019, 2016, 2015 by perlancar <perlancar@cpan.org>.
@@ -593,4 +602,12 @@ This software is copyright (c) 2021, 2020, 2019, 2016, 2015 by perlancar <perlan
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dateseq>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
